package com.jtricks.servlet;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintWriter;
import java.util.Properties;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.atlassian.jira.component.ComponentAccessor;
import com.atlassian.jira.config.util.JiraHome;
import com.atlassian.plugin.util.ClassLoaderUtils;

public class ReadPropertyServlet extends HttpServlet {
	private static final Logger log = LoggerFactory.getLogger(ReadPropertyServlet.class);

	@Override
	protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
		resp.setContentType("text/html");
		PrintWriter writer = resp.getWriter();
		writer.println("Reading from the WEB-INF/classes property file...<br><br>");

		InputStream iStream = null;
		try {
			iStream = ClassLoaderUtils.getResourceAsStream("jtricks.properties", this.getClass());
			Properties p = new Properties();
			p.load(iStream);
			writer.println("Reading property with key: <b>test.key</b><br>");
			writer.println("Value: <b>" + p.getProperty("test.key") + "</b><br><br>");
		} catch (Exception e) {
			log.error("Error reading property", e);
		} finally {
			if (iStream != null){
				iStream.close();
			}
		}

		writer.println("Reading from the Home property file...<br><br>");

		FileInputStream fileInputStream = null;
		try {
			File jiraHome = ComponentAccessor.getComponent(JiraHome.class).getHome();
			File propertyFile = new File(jiraHome, "jtricks-home.properties");
			fileInputStream = new FileInputStream(propertyFile);
			Properties p = new Properties();
			p.load(fileInputStream);
			writer.println("Reading property with key: <b>test.key</b><br>");
			writer.println("Value: <b>" + p.getProperty("test.key") + "</b><br>");
		} catch (Exception e) {
			log.error("Error reading property", e);
		} finally {
			if (fileInputStream != null)
				fileInputStream.close();
		}

		writer.println("Done\n");
	}

}